@@ -94,10 +94,10 @@ class ClickReviewSecurity(ClickReview):
         self.allowed_push_helper_policy_groups = ['push-notification-client']
         self.allowed_network_scope_policy_groups = ['accounts', 'networking']
         self.required_ubuntu_account_plugin_policy_groups = ['accounts',
-                                                             'networking',
-                                                             'webview']
+                                                             'networking']
         self.allowed_ubuntu_account_plugin_policy_groups = \
-            self.required_ubuntu_account_plugin_policy_groups
+            self.required_ubuntu_account_plugin_policy_groups + \
+            ['audio', 'webview']
 
         self.redflag_templates = ['unconfined']
         # TODO: how to deal with other vendors
@@ -986,20 +986,37 @@ class ClickReviewSecurity(ClickReview):
     def _convert_click_security_to_yaml(self):
         '''Convert click manifest to yaml'''
         converted = dict()
+
+        # The click compat manifest does not have a 1 to 1 mapping to
+        # package.yaml (ie, can't differentiate between services and
+        # binaries) so look the appname up in the package.yaml to know
+        # if it is a service or binary
+        yaml_services = []
+        if 'services' in self.pkg_yaml:
+            yaml_services = [e['name'] for e in self.pkg_yaml['services']
+                             if 'name' in e]
+        yaml_binaries = []
+        if 'binaries' in self.pkg_yaml:
+            for e in self.pkg_yaml['binaries']:
+                if 'exec' in e:
+                    yaml_binaries.append(e['name'])
+                else:
+                    yaml_binaries.append(e['name'].split('/')[-1])
+
         for app in sorted(self.security_apps):
-            if 'snappy-systemd' in self.manifest['hooks'][app]:
-                key = 'services'
-            elif 'bin-path' in self.manifest['hooks'][app]:
-                key = 'binaries'
-            elif app == 'snappy-config':
+            if app == 'snappy-config':
                 # the apparmor policy for snappy-config is autogenerated and
                 # not represented in the yaml
                 continue
+
+            if app in yaml_services:
+                key = 'services'
+            elif app in yaml_binaries:
+                key = 'binaries'
             else:
                 t = 'error'
-                n = 'yaml_click_%s' % app
-                s = "click manifest missing 'snappy-systemd/bin-path' for " + \
-                    "'%s'" % app
+                n = 'yaml_and_click_%s' % app
+                s = "'%s' in click manifest missing from package.yaml" % app
                 self._add_result(t, n, s)
                 continue
 
@@ -1018,15 +1035,14 @@ class ClickReviewSecurity(ClickReview):
             converted[key].append(copy.deepcopy(tmp))
 
         for app in sorted(self.security_apps_profiles):
-            if 'snappy-systemd' in self.manifest['hooks'][app]:
+            if app in yaml_services:
                 key = 'services'
-            elif 'bin-path' in self.manifest['hooks'][app]:
+            elif app in yaml_binaries:
                 key = 'binaries'
             else:
                 t = 'error'
-                n = 'yaml_click_%s' % app
-                s = "click manifest missing 'snappy-systemd/bin-path' for " + \
-                    "'%s'" % app
+                n = 'yaml_and_click_%s' % app
+                s = "'%s' in click manifest missing from package.yaml" % app
                 self._add_result(t, n, s)
                 continue
 
