@@ -21,6 +21,9 @@ from clickreviews.cr_lint import MINIMUM_CLICK_FRAMEWORK_VERSION
 from clickreviews.frameworks import FRAMEWORKS_DATA_URL, USER_DATA_FILE
 import clickreviews.cr_tests as cr_tests
 
+import os
+import stat
+
 
 class TestClickReviewLint(cr_tests.TestClickReview):
     """Tests for the lint review tool."""
@@ -30,6 +33,30 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         cr_tests.mock_patch()
         super()
 
+    def _create_hashes_yaml(self):
+        # find cr_tests.py since that is what _get_statinfo() is mocked to
+        # look at.
+        f = os.path.join(os.path.dirname(os.path.realpath(__file__)),
+                         "../cr_tests.py")
+        statinfo = os.stat(f)
+        self.sha512 = cr_tests._get_sha512sum(self, f)
+        hashes = {'archive-sha512': self.sha512,
+                  'files': [{'name': 'bin',
+                             'mode': 'drwxrwxr-x'},
+                            {'name': 'bin/foo',
+                             'size': statinfo.st_size,
+                             'mode': 'f%s' %
+                                     stat.filemode(statinfo.st_mode)[1:],
+                             'sha512': self.sha512},
+                            {'name': 'barlink',
+                             'mode': 'lrwxrwxrwx'},
+                            ]
+                  }
+        self._test_pkg_files = []
+        for i in hashes['files']:
+            self._test_pkg_files.append(i['name'])
+        return hashes
+
     def patch_frameworks(self):
         def _mock_frameworks(self, overrides=None):
             self.FRAMEWORKS = {
@@ -481,14 +508,25 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         self.check_results(r, expected_counts)
 
     def test_check_maintainer_missing(self):
-        '''Test check_maintainer() - missing'''
+        '''Test check_maintainer() - missing (click)'''
         self.set_test_manifest("maintainer", None)
         c = ClickReviewLint(self.test_name)
+        c.is_snap = False
         c.check_maintainer()
         r = c.click_report
         expected_counts = {'info': 0, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
+    def test_check_maintainer_missing_snap(self):
+        '''Test check_maintainer() - missing (snap)'''
+        self.set_test_manifest("maintainer", None)
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        c.check_maintainer()
+        r = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
     def test_check_maintainer_badformat(self):
         '''Test check_maintainer() - badly formatted'''
         self.set_test_manifest("maintainer", "$%^@*")
@@ -883,31 +921,64 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         self.check_results(r, expected_counts)
         self.check_manual_review(r, 'lint_hooks_redflag_test-app')
 
-    def test_snappy_name1(self):
+    def test_pkgname_toplevel(self):
+        '''Test check_pkgname - toplevel'''
+        self.set_test_manifest("name", "foo")
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = False
+        c.check_pkgname()
+        r = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_pkgname_flat(self):
+        '''Test check_pkgname - flat'''
+        self.set_test_manifest("name", "foo.bar")
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = False
+        c.check_pkgname()
+        r = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_pkgname_reverse_domain(self):
+        '''Test check_pkgname - reverse domain'''
+        self.set_test_manifest("name", "com.ubuntu.develeper.baz.foo")
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = False
+        c.check_pkgname()
+        r = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_snappy_name_toplevel(self):
         '''Test check_snappy_name - toplevel'''
         self.set_test_pkg_yaml("name", "foo")
         c = ClickReviewLint(self.test_name)
+        c.is_snap = True
         c.check_snappy_name()
         r = c.click_report
         expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
-    def test_snappy_name2(self):
-        '''Test check_snappy_name - flat'''
+    def test_snappy_name_flat(self):
+        '''Test check_snappy_name - obsoleted flat'''
         self.set_test_pkg_yaml("name", "foo.bar")
         c = ClickReviewLint(self.test_name)
+        c.is_snap = True
         c.check_snappy_name()
         r = c.click_report
-        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
-    def test_snappy_name3(self):
-        '''Test check_snappy_name - reverse domain'''
+    def test_snappy_name_reverse_domain(self):
+        '''Test check_snappy_name - obsoleted reverse domain'''
         self.set_test_pkg_yaml("name", "com.ubuntu.develeper.baz.foo")
         c = ClickReviewLint(self.test_name)
+        c.is_snap = True
         c.check_snappy_name()
         r = c.click_report
-        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
     def test_snappy_name_bad(self):
@@ -1357,3 +1428,366 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         r = c.click_report
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
+
+    def test_check_snappy_services_and_binaries1(self):
+        '''Test check_snappy_services_and_binaries() - different'''
+        self.set_test_pkg_yaml("name", self.test_name.split('_')[0])
+        self.set_test_pkg_yaml("services", [{"name": "foo",
+                                             "start": "bin/foo"}])
+        self.set_test_pkg_yaml("binaries", [{"name": "bar"}])
+        c = ClickReviewLint(self.test_name)
+        c.check_snappy_services_and_binaries()
+        r = c.click_report
+        expected_counts = {'info': 2, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_snappy_services_and_binaries2(self):
+        '''Test check_snappy_services_and_binaries() - different (exec)'''
+        self.set_test_pkg_yaml("name", self.test_name.split('_')[0])
+        self.set_test_pkg_yaml("services", [{"name": "foo",
+                                             "start": "bin/foo"}])
+        self.set_test_pkg_yaml("binaries", [{"name": "bar",
+                                             "exec": "bin/foo"}])
+        c = ClickReviewLint(self.test_name)
+        c.check_snappy_services_and_binaries()
+        r = c.click_report
+        expected_counts = {'info': 2, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_snappy_services_and_binaries3(self):
+        '''Test check_snappy_services_and_binaries() - same'''
+        self.set_test_pkg_yaml("name", self.test_name.split('_')[0])
+        self.set_test_pkg_yaml("services", [{"name": "foo",
+                                             "start": "bin/foo"}])
+        self.set_test_pkg_yaml("binaries", [{"name": "foo"}])
+        c = ClickReviewLint(self.test_name)
+        c.check_snappy_services_and_binaries()
+        r = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 2}
+        self.check_results(r, expected_counts)
+
+        m = r['error']['lint_snappy_foo_in_services']['text']
+        self.assertIn("'foo' in both 'services' and 'binaries'", m)
+        m = r['error']['lint_snappy_foo_in_binaries']['text']
+        self.assertIn("'foo' in both 'services' and 'binaries'", m)
+
+    def test_check_snappy_services_and_binaries4(self):
+        '''Test check_snappy_services_and_binaries() - same (subdir)'''
+        self.set_test_pkg_yaml("name", self.test_name.split('_')[0])
+        self.set_test_pkg_yaml("services", [{"name": "foo",
+                                             "start": "bin/foo"}])
+        self.set_test_pkg_yaml("binaries", [{"name": "bin/foo"}])
+        c = ClickReviewLint(self.test_name)
+        c.check_snappy_services_and_binaries()
+        r = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 2}
+        self.check_results(r, expected_counts)
+
+        m = r['error']['lint_snappy_foo_in_services']['text']
+        self.assertIn("'foo' in both 'services' and 'binaries'", m)
+        m = r['error']['lint_snappy_foo_in_binaries']['text']
+        self.assertIn("'foo' in both 'services' and 'binaries'", m)
+
+    def test_check_snappy_services_and_binaries5(self):
+        '''Test check_snappy_services_and_binaries() - same (exec, subdir)'''
+        self.set_test_pkg_yaml("name", self.test_name.split('_')[0])
+        self.set_test_pkg_yaml("services", [{"name": "foo",
+                                             "start": "bin/foo"}])
+        self.set_test_pkg_yaml("binaries", [{"name": "foo",
+                                             "exec": "bin/foo"}])
+        c = ClickReviewLint(self.test_name)
+        c.check_snappy_services_and_binaries()
+        r = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 2}
+        self.check_results(r, expected_counts)
+
+        m = r['error']['lint_snappy_foo_in_services']['text']
+        self.assertIn("'foo' in both 'services' and 'binaries'", m)
+        m = r['error']['lint_snappy_foo_in_binaries']['text']
+        self.assertIn("'foo' in both 'services' and 'binaries'", m)
+
+    def test_check_snappy_hashes_click(self):
+        '''Test check_snappy_hashes() - click'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = False
+        c.check_snappy_hashes()
+        r = c.click_report
+        # clicks don't have hashes.yaml, so should have no output
+        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_snappy_hashes_archive_sha512_missing(self):
+        '''Test check_snappy_hashes() - archive-sha512 missing'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
+    def test_check_snappy_hashes_archive_sha512_invalid(self):
+        '''Test check_snappy_hashes() - archive-sha512 invalid'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        yaml = self._create_hashes_yaml()
+        yaml['archive-sha512'] = 'deadbeef'
+        self.set_test_hashes_yaml(yaml)
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+        m = r['error']['lint_hashes_archive-sha512_valid']['text']
+        self.assertIn("hash mismatch: 'deadbeef' != '%s'" % self.sha512, m)
+
+    def test_check_snappy_hashes_archive_files_missing(self):
+        '''Test check_snappy_hashes() - files missing'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        yaml = self._create_hashes_yaml()
+        del yaml['files']
+        self.set_test_hashes_yaml(yaml)
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+        m = r['error']['lint_hashes_files_present']['text']
+        self.assertIn("'files' not found in hashes.yaml", m)
+
+    def test_check_snappy_hashes_archive_files_ok(self):
+        '''Test check_snappy_hashes() - ok'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        yaml = self._create_hashes_yaml()
+        c.pkg_files = self._test_pkg_files
+        self.set_test_hashes_yaml(yaml)
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': 4, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_snappy_hashes_archive_files_missing_name(self):
+        '''Test check_snappy_hashes() - missing name'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        yaml = self._create_hashes_yaml()
+        del yaml['files'][0]['name']
+        self.set_test_hashes_yaml(yaml)
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
+    def test_check_snappy_hashes_archive_files_missing_mode(self):
+        '''Test check_snappy_hashes() - missing mode'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        yaml = self._create_hashes_yaml()
+        del yaml['files'][0]['mode']
+        self.set_test_hashes_yaml(yaml)
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
+    def test_check_snappy_hashes_archive_files_malformed_mode(self):
+        '''Test check_snappy_hashes() - malformed mode'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        yaml = self._create_hashes_yaml()
+        yaml['files'][0]['mode'] += 'extra'
+        self.set_test_hashes_yaml(yaml)
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
+    def test_check_snappy_hashes_archive_files_bad_mode_entry(self):
+        '''Test check_snappy_hashes() - bad mode entry'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        yaml = self._create_hashes_yaml()
+        count = 0
+        orig_mode = None
+        for e in yaml['files']:
+            s = list(yaml['files'][count]['mode'])
+            if e['name'] == 'bin/foo':
+                # keep track of the other parts of the on disk mode
+                orig_mode = s
+                orig_mode[3] = 'S'
+                s[3] = 'S'
+            yaml['files'][count]['mode'] = "".join(s)
+            count += 1
+        self.set_test_hashes_yaml(yaml)
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+        m = r['error']['lint_file_mode']['text']
+        self.assertIn("found errors in hashes.yaml: unusual mode '%s' for entry 'bin/foo'" % "".join(orig_mode), m)
+
+    def test_check_snappy_hashes_archive_files_mode_world_write(self):
+        '''Test check_snappy_hashes() - mode world write'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        yaml = self._create_hashes_yaml()
+        count = 0
+        for e in yaml['files']:
+            s = list(e['mode'])
+            if e['name'] == 'bin/foo' or e['name'] == 'bin':
+                s[-2] = 'w'
+                s[-5] = 'w'
+            yaml['files'][count]['mode'] = "".join(s)
+            count += 1
+        self.set_test_hashes_yaml(yaml)
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+        m = r['error']['lint_file_mode']['text']
+        self.assertIn("found errors in hashes.yaml: 'bin' is world-writable, mode 'frw-rw-rw-' for 'bin/foo' is world-writable", m)
+
+    def test_check_snappy_hashes_archive_files_mode_mismatch(self):
+        '''Test check_snappy_hashes() - mode mismatch'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        yaml = self._create_hashes_yaml()
+        count = 0
+        orig_mode = None
+        for e in yaml['files']:
+            if e['mode'].startswith('f'):
+                # keep track of the other parts of the on disk mode
+                orig_mode = e['mode'][1:]
+                yaml['files'][count]['mode'] = "f---------"
+                break
+            count += 1
+        self.set_test_hashes_yaml(yaml)
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+        m = r['error']['lint_file_mode']['text']
+        self.assertIn("found errors in hashes.yaml: mode '---------' != '%s' for 'bin/foo'" % orig_mode, m)
+
+    def test_check_snappy_hashes_archive_files_mode_bad_symlink(self):
+        '''Test check_snappy_hashes() - mode bad symlink'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        yaml = self._create_hashes_yaml()
+        yaml['files'].append({'name': 'badlink', 'mode': 'lrwxrwxr-x'})
+        self.set_test_hashes_yaml(yaml)
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+        m = r['error']['lint_file_mode']['text']
+        self.assertIn("found errors in hashes.yaml: unusual mode 'lrwxrwxr-x' for entry 'badlink'", m)
+
+    def test_check_snappy_hashes_archive_files_mode_devices(self):
+        '''Test check_snappy_hashes() - mode devices'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        yaml = self._create_hashes_yaml()
+        yaml['files'].append({'name': 'badblock', 'mode': 'brw-rw-r--'})
+        yaml['files'].append({'name': 'badchar', 'mode': 'crw-rw-r--'})
+        self.set_test_hashes_yaml(yaml)
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+        m = r['error']['lint_file_mode']['text']
+        self.assertIn("found errors in hashes.yaml: illegal file mode 'b': 'brw-rw-r--' for 'badblock', illegal file mode 'c': 'crw-rw-r--' for 'badchar'", m)
+
+    def test_check_snappy_hashes_archive_files_missing_size(self):
+        '''Test check_snappy_hashes() - missing size'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        yaml = self._create_hashes_yaml()
+        count = 0
+        for e in yaml['files']:
+            if e['mode'].startswith('f'):
+                del yaml['files'][count]['size']
+                break
+            count += 1
+        self.set_test_hashes_yaml(yaml)
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
+    def test_check_snappy_hashes_archive_files_invalid_size(self):
+        '''Test check_snappy_hashes() - invalid size'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        yaml = self._create_hashes_yaml()
+        count = 0
+        for e in yaml['files']:
+            if e['mode'].startswith('f'):
+                orig_size = e['size']
+                new_size = orig_size + 1
+                yaml['files'][count]['size'] = new_size
+                break
+            count += 1
+        self.set_test_hashes_yaml(yaml)
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+        m = r['error']['lint_file_mode']['text']
+        self.assertIn("found errors in hashes.yaml: size " +
+                      "%d != %d for 'bin/foo'" % (new_size, orig_size), m)
+
+    def test_check_snappy_hashes_archive_files_missing_sha512(self):
+        '''Test check_snappy_hashes() - missing sha512'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        yaml = self._create_hashes_yaml()
+        count = 0
+        for e in yaml['files']:
+            if e['mode'].startswith('f'):
+                del yaml['files'][count]['sha512']
+                break
+            count += 1
+        self.set_test_hashes_yaml(yaml)
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
+    def test_check_snappy_hashes_extra(self):
+        '''Test check_snappy_hashes() - extra'''
+        c = ClickReviewLint(self.test_name)
+        c.is_snap = True
+        yaml = self._create_hashes_yaml()
+        self.set_test_hashes_yaml(yaml)
+        c.pkg_files = self._test_pkg_files
+        c.pkg_files.append("extrafile")
+        c.check_snappy_hashes()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+        m = r['error']['lint_hashes_extra_files']['text']
+        self.assertIn("found extra files not listed in hashes.yaml: extrafile",
+                      m)
+
+    def test_snappy_config(self):
+        '''Test check_snappy_config()'''
+        c = ClickReviewLint(self.test_name)
+        c.unpack_dir = "/nonexistent"
+        c.pkg_files.append(os.path.join(c.unpack_dir, 'meta/hooks/config'))
+        c.is_snap = True
+        c.check_snappy_config()
+        r = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_snappy_config_nonexecutable(self):
+        '''Test check_snappy_config() - not executable'''
+        c = ClickReviewLint(self.test_name)
+        c.unpack_dir = "/nonexistent.nonexec"
+        c.pkg_files.append(os.path.join(c.unpack_dir,
+                                        'meta/hooks/config'))
+        c.is_snap = True
+        c.check_snappy_config()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
